@@ -203,18 +203,19 @@ ReversiGame::startNextTurn()
     {
         undoEnabled_ = !undoInfo_.isEmpty();
         emit enableUndo(undoEnabled_);
+    }
 
-        if(isComputersTurn())
+    if ((mode_ == 1 || mode_ == 2) && isComputersTurn())
+    {
+
+        if (isStepAvailable())
+            computerMove();
+        else
         {
-            if (isStepAvailable())
-                computerMove();
-            else
-            {
-                emit stepUnavailable();
-                switchPlayer();
-                emit updateInfo();
-            } /*         else */
-        }
+            emit stepUnavailable();
+            switchPlayer();
+            emit updateInfo();
+        } /*         else */
     }
     else
     {
